==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/DataLegendStylingColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingColumnEventArgsDescription } from "./DataLegendStylingColumnEventArgsDescription";
/**
 * @hidden
 */
var DataLegendStylingColumnEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendStylingColumnEventArgsDescriptionMetadata, _super);
    function DataLegendStylingColumnEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendStylingColumnEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendStylingColumnEventArgsDescriptionMetadata.a == null) {
            DataLegendStylingColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendStylingColumnEventArgsDescriptionMetadata.c(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
        if (a.k(DataLegendStylingColumnEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.c = function (a) {
        a.item("ColumnIndex", "Number:int");
        a.item("SeriesIndex", "Number:int");
        a.item("SeriesTitle", "String");
        a.item("ValueOriginal", "Number:double");
        a.item("ValueMemberPath", "String");
        a.item("ValueMemberLabel", "String");
        a.item("ValueAbbreviation", "ExportedType:string:DataAbbreviationMode");
        a.item("ValueAbbreviation@names", "Auto;Independent;Shared;Kilo;Million;Billion;Trillion;Quadrillion;Unset;None");
        a.item("LabelText", "String");
        a.item("UnitsText", "String");
        a.item("ValueText", "String");
        a.item("LabelTextColor", "Brush");
        a.item("UnitsTextColor", "Brush");
        a.item("ValueTextColor", "Brush");
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.d = function (a) {
        DataLegendStylingColumnEventArgsDescriptionMetadata.b(a);
        a.ad("DataLegendStylingColumnEventArgs", function () { return new DataLegendStylingColumnEventArgsDescription(); });
        a.ac("DataLegendStylingColumnEventArgs", DataLegendStylingColumnEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.$t = markType(DataLegendStylingColumnEventArgsDescriptionMetadata, 'DataLegendStylingColumnEventArgsDescriptionMetadata');
    DataLegendStylingColumnEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingColumnEventArgsDescriptionMetadata;
}(Base));
export { DataLegendStylingColumnEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/DataLegendStylingColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendStylingColumnEventArgsDescription } from "./DataLegendStylingColumnEventArgsDescription";
/**
 * @hidden
 */
var DataLegendStylingColumnEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataLegendStylingColumnEventArgsDescriptionMetadata, _super);
    function DataLegendStylingColumnEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendStylingColumnEventArgsDescriptionMetadata.b = function (a) {
        if (DataLegendStylingColumnEventArgsDescriptionMetadata.a == null) {
            DataLegendStylingColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendStylingColumnEventArgsDescriptionMetadata.c(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
        }
        if (a.k(DataLegendStylingColumnEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(DataLegendStylingColumnEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.c = function (a) {
        a.item("ColumnIndex", "Number:int");
        a.item("SeriesIndex", "Number:int");
        a.item("SeriesTitle", "String");
        a.item("ValueOriginal", "Number:double");
        a.item("ValueMemberPath", "String");
        a.item("ValueMemberLabel", "String");
        a.item("ValueAbbreviation", "ExportedType:string:DataAbbreviationMode");
        a.item("ValueAbbreviation@names", "Auto;Independent;Shared;Kilo;Million;Billion;Trillion;Quadrillion;Unset;None");
        a.item("LabelText", "String");
        a.item("UnitsText", "String");
        a.item("ValueText", "String");
        a.item("LabelTextColor", "Brush");
        a.item("UnitsTextColor", "Brush");
        a.item("ValueTextColor", "Brush");
        a.item("GroupName", "String");
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.d = function (a) {
        DataLegendStylingColumnEventArgsDescriptionMetadata.b(a);
        a.ae("DataLegendStylingColumnEventArgs", function () { return new DataLegendStylingColumnEventArgsDescription(); });
        a.ad("DataLegendStylingColumnEventArgs", DataLegendStylingColumnEventArgsDescriptionMetadata.a);
    };
    DataLegendStylingColumnEventArgsDescriptionMetadata.$t = markType(DataLegendStylingColumnEventArgsDescriptionMetadata, 'DataLegendStylingColumnEventArgsDescriptionMetadata');
    DataLegendStylingColumnEventArgsDescriptionMetadata.a = null;
    return DataLegendStylingColumnEventArgsDescriptionMetadata;
}(Base));
export { DataLegendStylingColumnEventArgsDescriptionMetadata };
